==> flutter_autosize_screen-0.1.1.tar.gz: example/lib/main_test.dart <==
import 'dart:ui';

import 'package:flutter/material.dart';
import 'package:flutter_autosize_screen/auto_size_util.dart';
import 'package:flutter_autosize_screen/binding.dart';

void main() {
  AutoSizeUtil.setStandard(180);
  runAutoApp(const MyApp());
  // runApp(const MyApp());
}

class MyApp extends StatelessWidget {
  const MyApp({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Autosize Demo',
      builder: AutoSizeUtil.appBuilder,
      theme: ThemeData(
        primarySwatch: Colors.blue,
      ),
      home: HomePage(),
    );
  }
}

class HomePage extends StatefulWidget {
  const HomePage({Key? key}) : super(key: key);

  @override
  State<HomePage> createState() => _HomePageState();
}

class _HomePageState extends State<HomePage> {
  GlobalKey _key57 = GlobalKey();
  GlobalKey _keyBlue = GlobalKey();
  GlobalKey _keyAppbar = GlobalKey();

  @override
  void initState() {
    super.initState();
    WidgetsBinding.instance!.addPostFrameCallback((timeStamp) {
      var renderBox = _key57.currentContext!.findRenderObject()!.paintBounds;
      var sizeGreen = renderBox.size;
      print("${sizeGreen.width} ----- ${sizeGreen.height}");

      var renderBlu = _keyBlue.currentContext!.findRenderObject()!.paintBounds;
      var sizeBlue = renderBlu.size;
      print("${sizeBlue.width} ----- ${sizeBlue.height}");


      var _renderKeyAppbar = _keyAppbar.currentContext!.findRenderObject()!.paintBounds;
      var _keyAppbarSize = _renderKeyAppbar.size;
      print("${_keyAppbarSize.width} ----- ${_keyAppbarSize.height}");

      // print("${AutoSizeUtil.getScreenSize()}");
    });
  }

  @override
  Widget build(BuildContext context) {

    print("-----------appBarTheme----------");
    print(Theme.of(context).appBarTheme);
    print("------------iconTheme---------");
    print(Theme.of(context).iconTheme);

    print("------------bannerTheme---------");
    print(Theme.of(context).bannerTheme);

    print("------------bottomAppBarTheme---------");
    print(Theme.of(context).bottomAppBarTheme);

    print("------------bottomNavigationBarTheme---------");
    print(Theme.of(context).bottomNavigationBarTheme);

    print("------------tabBarTheme---------");
    print(Theme.of(context).tabBarTheme);

    print("------------textButtonTheme---------");
    print(Theme.of(context).textButtonTheme);

    print("------------bottomSheetTheme---------");
    print(Theme.of(context).bottomSheetTheme);

    print("------------buttonTheme---------");
    print(Theme.of(context).buttonTheme);

    print("------------buttonBarTheme---------");
    print(Theme.of(context).buttonBarTheme);

    print("------------cardTheme---------");
    print(Theme.of(context).cardTheme);

    print("------------checkboxTheme---------");
    print(Theme.of(context).checkboxTheme);

    print("------------chipTheme---------");
    print(Theme.of(context).chipTheme);

    print("------------cupertinoOverrideTheme---------");
    print(Theme.of(context).cupertinoOverrideTheme);

    print("------------textSelectionTheme---------");
    print(Theme.of(context).textSelectionTheme);

    print("------------timePickerTheme---------");
    print(Theme.of(context).timePickerTheme);

    print("------------dataTableTheme---------");
    print(Theme.of(context).dataTableTheme);

    print("------------dividerTheme---------");
    print(Theme.of(context).dividerTheme);

    print("------------dialogTheme---------");
    print(Theme.of(context).dialogTheme);

    print("------------elevatedButtonTheme---------");
    print(Theme.of(context).elevatedButtonTheme);

    print("------------floatingActionButtonTheme---------");
    print(Theme.of(context).floatingActionButtonTheme);

    print("------------tooltipTheme---------");
    print(Theme.of(context).tooltipTheme);

    print("------------switchTheme---------");
    print(Theme.of(context).switchTheme);

    print("------------snackBarTheme---------");
    print(Theme.of(context).snackBarTheme);

    print("------------sliderTheme---------");
    print(Theme.of(context).sliderTheme);

    print("------------inputDecorationTheme---------");
    print(Theme.of(context).inputDecorationTheme);

    print("------------navigationRailTheme---------");
    print(Theme.of(context).navigationRailTheme);

    print("------------pageTransitionsTheme---------");
    print(Theme.of(context).pageTransitionsTheme);

    print("------------outlinedButtonTheme---------");
    print(Theme.of(context).outlinedButtonTheme);
    return Scaffold(
      appBar: AppBar(
        title: Text("Autosize Demo"),
      ),
      body: Column(
        children: [
          PreferredSize(
              child: AppBar(key: _key57,title: Text("固定60"),backgroundColor: Colors.purple,actions: [Icon(Icons.add)],),
              preferredSize: Size.fromHeight(60)),
          AppBar(
            backgroundColor: Colors.red,
            key: _keyAppbar,
            title: Text("默认"),
          ),

          Checkbox(value: true, onChanged: (isChed){}),
          Expanded(
            child: Center(
              child: Icon(Icons.add, key: _keyBlue),
            ),
          )
        ],
      ),
    );
  }
}

==> flutter_autosize_screen-0.1.3.tar.gz: example/lib/main_test.dart <==
import 'dart:ui';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_autosize_screen/auto_size_util.dart';
import 'package:flutter_autosize_screen/binding.dart';

void main() {
  AutoSizeUtil.setStandard(180);
  runAutoApp(const MyApp());
  // runApp(const MyApp());
}

class MyApp extends StatelessWidget {
  const MyApp({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Autosize Demo',
      builder: AutoSizeUtil.appBuilder,
      theme: ThemeData(
        primarySwatch: Colors.blue,
      ),
      home: HomePage(),
    );
  }
}

class HomePage extends StatefulWidget {
  const HomePage({Key? key}) : super(key: key);

  @override
  State<HomePage> createState() => _HomePageState();
}

class _HomePageState extends State<HomePage> {
  GlobalKey _key57 = GlobalKey();
  GlobalKey _app = GlobalKey();
  GlobalKey _keyBlue = GlobalKey();
  GlobalKey _keyAppbar = GlobalKey();

  @override
  void initState() {
    super.initState();
    WidgetsBinding.instance!.addPostFrameCallback((timeStamp) {

      var _appBox = _app.currentContext!.findRenderObject()!.paintBounds;
      var appSize = _appBox.size;
      print("${appSize.width} ----- ${appSize.height}");

   var renderBox = _key57.currentContext!.findRenderObject()!.paintBounds;
      var sizeGreen = renderBox.size;
      print("${sizeGreen.width} ----- ${sizeGreen.height}");

      var renderBlu = _keyBlue.currentContext!.findRenderObject()!.paintBounds;
      var sizeBlue = renderBlu.size;
      print("${sizeBlue.width} ----- ${sizeBlue.height}");

      var _renderKeyAppbar =
          _keyAppbar.currentContext!.findRenderObject()!.paintBounds;
      var _keyAppbarSize = _renderKeyAppbar.size;
      print("${_keyAppbarSize.width} ----- ${_keyAppbarSize.height}");

      // print("${AutoSizeUtil.getScreenSize()}");
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        key: _app,
        title: Text("Autosize Demo"),
      ),
      floatingActionButton: FloatingActionButton(
        child: Icon(Icons.add),
        onPressed: () {},
      ),
      body: Column(
        children: [
          PreferredSize(
              child: AppBar(
                key: _key57,
                title: Text("固定60"),
                backgroundColor: Colors.purple,
                actions: [Icon(Icons.add)],
              ),
              preferredSize: Size.fromHeight(80)),
          AppBar(
            backgroundColor: Colors.red,
            key: _keyAppbar,
            title: Text("默认"),
          ),
          Checkbox(value: true, onChanged: (isChed) {}),
          Switch(value: true, onChanged: (isChed) {}),
          CupertinoSwitch(value: true, onChanged: (isChed) {}),
          MaterialButton(onPressed: (){},child: Text("大家好哦"),),
          Radio(
            value: true,
            onChanged: (isChed) {},
            groupValue: "",
          ),
          Expanded(
            child: Center(
              child: Icon(Icons.add, key: _keyBlue),
            ),
          )
        ],
      ),
    );
  }
}
